@@ -13,6 +13,7 @@ class MjpegParser(object):
     self.quality = 50
     self.format = 'jpeg'
     self.input = urllib2.urlopen(url)
+    self.length = 0
 
   def serve(self):
     while True:
@@ -24,6 +25,7 @@ class MjpegParser(object):
           length = regex.findall(content)
           if len(length) >= 1:
             content_length = int(length[0])
+            self.length = content_length
         content = self.input.readline()
         data = self.input.read(content_length)
 
@@ -33,4 +35,5 @@ class MjpegParser(object):
           im.save(output, format=self.format, quality=self.quality)
           output.seek(0)
           # it return file-like object in memory
+          self.length = output.len
           return output
